==> knative-model-4.7.1-sources.jar: io/fabric8/knative/serving/v1alpha1/ReleaseTypeFluent.java <==
package io.fabric8.knative.serving.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ReleaseTypeFluent<A extends ReleaseTypeFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildConfiguration instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.serving.v1alpha1.ConfigurationSpec getConfiguration();
    public io.fabric8.knative.serving.v1alpha1.ConfigurationSpec buildConfiguration();
    public A withConfiguration(io.fabric8.knative.serving.v1alpha1.ConfigurationSpec configuration);
    public Boolean hasConfiguration();
    public ReleaseTypeFluent.ConfigurationNested<A> withNewConfiguration();
    public ReleaseTypeFluent.ConfigurationNested<A> withNewConfigurationLike(io.fabric8.knative.serving.v1alpha1.ConfigurationSpec item);
    public ReleaseTypeFluent.ConfigurationNested<A> editConfiguration();
    public ReleaseTypeFluent.ConfigurationNested<A> editOrNewConfiguration();
    public ReleaseTypeFluent.ConfigurationNested<A> editOrNewConfigurationLike(io.fabric8.knative.serving.v1alpha1.ConfigurationSpec item);
    public A addToRevisions(int index,String item);
    public A setToRevisions(int index,String item);
    public A addToRevisions(String... items);
    public A addAllToRevisions(Collection<String> items);
    public A removeFromRevisions(String... items);
    public A removeAllFromRevisions(Collection<String> items);
    public List<String> getRevisions();
    public String getRevision(int index);
    public String getFirstRevision();
    public String getLastRevision();
    public String getMatchingRevision(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingRevision(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withRevisions(List<String> revisions);
    public A withRevisions(String... revisions);
    public Boolean hasRevisions();
    public A addNewRevision(String arg1);
    public A addNewRevision(StringBuilder arg1);
    public A addNewRevision(StringBuffer arg1);
    public Integer getRolloutPercent();
    public A withRolloutPercent(Integer rolloutPercent);
    public Boolean hasRolloutPercent();

    public interface ConfigurationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1alpha1.ConfigurationSpecFluent<ReleaseTypeFluent.ConfigurationNested<N>>{

        
    public N and();    public N endConfiguration();
}


}

==> knative-model-4.10.0-sources.jar: io/fabric8/knative/serving/v1alpha1/ReleaseTypeFluent.java <==
package io.fabric8.knative.serving.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ReleaseTypeFluent<A extends ReleaseTypeFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildConfiguration instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public io.fabric8.knative.serving.v1alpha1.ConfigurationSpec getConfiguration();
    public io.fabric8.knative.serving.v1alpha1.ConfigurationSpec buildConfiguration();
    public A withConfiguration(io.fabric8.knative.serving.v1alpha1.ConfigurationSpec configuration);
    public Boolean hasConfiguration();
    public ReleaseTypeFluent.ConfigurationNested<A> withNewConfiguration();
    public ReleaseTypeFluent.ConfigurationNested<A> withNewConfigurationLike(io.fabric8.knative.serving.v1alpha1.ConfigurationSpec item);
    public ReleaseTypeFluent.ConfigurationNested<A> editConfiguration();
    public ReleaseTypeFluent.ConfigurationNested<A> editOrNewConfiguration();
    public ReleaseTypeFluent.ConfigurationNested<A> editOrNewConfigurationLike(io.fabric8.knative.serving.v1alpha1.ConfigurationSpec item);
    public A addToRevisions(int index,String item);
    public A setToRevisions(int index,String item);
    public A addToRevisions(String... items);
    public A addAllToRevisions(Collection<String> items);
    public A removeFromRevisions(String... items);
    public A removeAllFromRevisions(Collection<String> items);
    public List<String> getRevisions();
    public String getRevision(int index);
    public String getFirstRevision();
    public String getLastRevision();
    public String getMatchingRevision(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingRevision(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withRevisions(List<String> revisions);
    public A withRevisions(String... revisions);
    public Boolean hasRevisions();
    public A addNewRevision(String arg1);
    public A addNewRevision(StringBuilder arg1);
    public A addNewRevision(StringBuffer arg1);
    public Integer getRolloutPercent();
    public A withRolloutPercent(Integer rolloutPercent);
    public Boolean hasRolloutPercent();

    public interface ConfigurationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1alpha1.ConfigurationSpecFluent<ReleaseTypeFluent.ConfigurationNested<N>>{

        
    public N and();    public N endConfiguration();
}


}
